@@ -21,7 +21,7 @@ class TabFit(QtWidgets.QWidget):
         # Exact spherical model is only available in developer mode
         self.settings = QtCore.QSettings()
         self.settings.setIniCodec("utf-8")
-        if not bool(int(self.settings.value("developer mode", "0"))):
+        if not bool(int(self.settings.value("advanced/developer mode", "0"))):
             models_av.remove("sneddon_spher")
             self.widget_method.hide()
         models_av.sort(key=lambda x: nmodel.models_available[x].model_name)
@@ -168,7 +168,8 @@ class TabFit(QtWidgets.QWidget):
             i.e. displaying the results in
             `self.table_parameters_fitted`.
         """
-        dev_mode = bool(int(self.settings.value("developer mode", "0")))
+        dev_mode = bool(int(
+            self.settings.value("advanced/developer mode", "0")))
         # segment
         segment = self.cb_segment.currentText().lower()
         # x axis
@@ -321,7 +322,8 @@ class TabFit(QtWidgets.QWidget):
 
     def fit_update_parameters(self, fdist):
         """Update the ancillary and initial parameters in the UI"""
-        dev_mode = bool(int(self.settings.value("developer mode", "0")))
+        dev_mode = bool(int(
+            self.settings.value("advanced/developer mode", "0")))
         model_key = self.fit_model.model_key
 
         # set the model
